macro_rules! details {
($($k:expr => $v:expr),* $(,)?) => { ... };
}Expand description
Macro that can be used to create log “details” more easily.
macro_rules! details {
($($k:expr => $v:expr),* $(,)?) => { ... };
}Macro that can be used to create log “details” more easily.