macro_rules! details {
($($k:expr_2021 => $v:expr_2021),* $(,)?) => { ... };
}Expand description
Macro that can be used to create log “details” more easily.
macro_rules! details {
($($k:expr_2021 => $v:expr_2021),* $(,)?) => { ... };
}Macro that can be used to create log “details” more easily.